# Partner3DGeeksMetadata

Please do not include any personally-identifying info or sensitive info in partner serializers

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**model** | **str** |  | 
**platform** | **str** |  | 
**octoprint_version** | **str** |  | 
**print_nanny_plugin_version** | **str** |  | [readonly] 
**print_nanny_client_version** | **str** |  | 
**verified** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


